<div align="center">
  <img src="https://www.frootlab.org/images/fig/vivid.svg" width=350px>
</div>

Vivid Code
==========

[![Building Status](https://travis-ci.org/frootlab/vivid.svg?branch=master)](https://travis-ci.org/frootlab/rian)
[![Documentation Status](https://readthedocs.org/projects/vivid/badge/?version=latest)](https://vivid.readthedocs.io/en/latest/?badge=latest)
[![PIP Version](https://badge.fury.io/py/vivid.svg)](https://badge.fury.io/py/vivid)

**Vivid Code** is a pioneering software framework for next generation data
analysis applications, that interconnects collaborative data science with
automated machine learning.

Based on the **Cloud-Assisted Meta programming** (CAMP) paradigm, the framework
allows the usage of **Currently Best Fitting** (CBF) algorithms. Before code
interpretation / compilation the concrete algorithms, that implement the CBF
specifications, are automatically chosen from local and public catalog servers,
that host and deploy the concrete algorithms. Thereby the specification is
constituted by a unique algorithm category, a data domain and a metric, which
substantiates the meaning of *Best Fitting* within the respective algorithm- and
data context. An example is the average prediction accuracy within a fixed set
of gold standard samples of the data domain (e.g. latin handwriting samples,
spoken word samples, TCGA gene expression data, etc.).

The Vivid Code framework allows the implementation of cutting edge enterprise
analytical applications, that are automatically kept up-to-date and therefore
**minimize their maintenance costs**. Also the Vivid Code framework facilitates
the publication, application, sharing and comparison of algorithms, within and
between workgroups.

All components of the Vivid Code framework are open source and based on the
[Python](https://www.python.org/) programming language.

Current Development Status
--------------------------

The individual components of the Vivid Code frame work are in different
development stages.
Rian currently is in *Pre-Alpha* development stage, which immediately follows
the *Planning* stage. This means, that at least some essential requirements of
Rian are not yet implemented.

Installation
------------

Comprehensive information and installation support is provided within the
[online manual](http://docs.frootlab.org/vivid). If you already have a
Python environment configured on your computer, you can install the latest
distributed version by using pip:

    $ pip install vivid

Documentation
-------------

The documentation of the latest distributed version is available as an [online
manual](http://docs.frootlab.org/vivid) and for download, given in the
formats [PDF](https://readthedocs.org/projects/vivid/downloads/pdf/latest/),
[EPUB](https://readthedocs.org/projects/vivid/downloads/epub/latest/) and
[HTML](https://readthedocs.org/projects/vivid/downloads/htmlzip/latest/).

Contributions
-------------

Contributors are very welcome! Feel free to report bugs, ideas and feature
requests to the [issue tracker](https://github.com/frootlab/vivid/issues),
provided by GitHub. Currently, as our team still is growing, we do not provide
any Contribution Guide Lines. So, if you are interested to help or to join the
team, we would be glad, to [hear about you](mailto:application@frootlab.org).

License
-------

All components of the Vivid Code frame work are open source software and
available free for any use under the
[GPLv3 license](https://www.gnu.org/licenses/gpl.html):

    © 2019 Frootlab Developers:
      Patrick Michl <patrick.michl@frootlab.org>
    © 2013-2019 Patrick Michl
